more muttng -> madmutt
[apps/madmutt.git] / init.h
diff --git a/init.h b/init.h
index ac29376..65d5e1f 100644 (file)
--- a/init.h
+++ b/init.h
@@ -35,7 +35,7 @@
 #define DT_SYN          9       /* synonym for another variable */
 #define DT_ADDR         10      /* e-mail address */
 #define DT_USER         11      /* user defined via $user_ */
-#define DT_SYS          12      /* pre-defined via $muttng_ */
+#define DT_SYS          12      /* pre-defined via $madmutt_ */
 
 #define DTYPE(x) ((x) & DT_MASK)
 
@@ -146,7 +146,7 @@ struct option_t MuttVars[] = {
    ** check only happens after the \fIfirst\fP edit of the file).  When set
    ** to \fIno\fP, composition will never be aborted.
    */
-  {"alias_file", DT_PATH, R_NONE, UL &AliasFile, "~/.muttngrc"},
+  {"alias_file", DT_PATH, R_NONE, UL &AliasFile, "~/.madmuttrc"},
   /*
    ** .pp
    ** The default file in which to save aliases created by the 
@@ -280,7 +280,7 @@ struct option_t MuttVars[] = {
   {"attach_remind_regexp", DT_RX, R_NONE, UL &AttachRemindRegexp, "attach"},
   /*
    ** .pp
** If this variable is non-empty, muttng will scan a message's contents
    ** before sending for this regular expression. If it is found, it will
    ** ask for what to do depending on the setting of $$abort_noattach.
    ** .pp
@@ -478,7 +478,7 @@ struct option_t MuttVars[] = {
    ** If it is \fIset\fP and Mutt-ng was build with gpgme support, the gpgme code for
    ** S/MIME and PGP will be used instead of the classic code.
    ** .pp
** \fBNote\fP: You need to use this option in your \fT.muttngrc\fP configuration
    ** file as it won't have any effect when used interactively.
    */
 
@@ -525,7 +525,7 @@ struct option_t MuttVars[] = {
    ** \fT-d\fP command line option.
    **
    ** .pp
** Currently, this number must be >= 0 and <= 5 and muttng
    ** must be started with \fT-d\fP to enable debugging at all;
    ** enabling at runtime is not possible.
    */
@@ -586,13 +586,13 @@ struct option_t MuttVars[] = {
    ** filtered message is read from the standard output.
    */
 #if defined(USE_DOTLOCK)
-  {"dotlock_program", DT_PATH, R_NONE, UL &MuttDotlock, "$muttng_bindir/muttng_dotlock"},
+  {"dotlock_program", DT_PATH, R_NONE, UL &MuttDotlock, "$madmutt_bindir/muttng_dotlock"},
   /*
    ** .pp
    ** Availability: Dotlock
    **
    ** .pp
-   ** Contains the path of the \fTmuttng_dotlock(1)\fP binary to be used by
+   ** Contains the path of the \fTmadmutt_dotlock(1)\fP binary to be used by
    ** Mutt-ng.
    */
 #endif
@@ -1001,7 +1001,7 @@ struct option_t MuttVars[] = {
    ** mailing list when this option is set, use the \fIlist-reply\fP
    ** function; \fIgroup-reply\fP will reply to both the sender and the
    ** list.
** Remember: This option works only for mailing lists which are explicitly set in your muttngrc
    ** configuration file.
    */
   {"imap_authenticators", DT_STR, R_NONE, UL &ImapAuthenticators, "" },
@@ -1413,45 +1413,45 @@ struct option_t MuttVars[] = {
    ** This specifies the folder into which read mail in your ``$$spoolfile''
    ** folder will be appended.
    */
-  {"muttng_version", DT_SYS, R_NONE, 0, VERSION },
+  {"madmutt_version", DT_SYS, R_NONE, 0, VERSION },
   /*
    ** .pp
** \fIThis is a read-only system property and specifies muttng's
    ** version string.\fP
    */
-  {"muttng_revision", DT_SYS, R_NONE, 0, MUTT_REVISION },
+  {"madmutt_revision", DT_SYS, R_NONE, 0, MUTT_REVISION },
   /*
    ** .pp
** \fIThis is a read-only system property and specifies muttng's
    ** subversion revision string.\fP
    */
-  {"muttng_sysconfdir", DT_SYS, R_NONE, 0, SYSCONFDIR },
+  {"madmutt_sysconfdir", DT_SYS, R_NONE, 0, SYSCONFDIR },
   /*
    ** .pp
    ** \fIThis is a read-only system property and specifies the
** directory containing the muttng system-wide configuration.\fP
    */
-  {"muttng_bindir", DT_SYS, R_NONE, 0, BINDIR },
+  {"madmutt_bindir", DT_SYS, R_NONE, 0, BINDIR },
   /*
    ** .pp
    ** \fIThis is a read-only system property and specifies the
** directory containing the muttng binary.\fP
    */
-  {"muttng_docdir", DT_SYS, R_NONE, 0, PKGDOCDIR },
+  {"madmutt_docdir", DT_SYS, R_NONE, 0, PKGDOCDIR },
   /*
    ** .pp
    ** \fIThis is a read-only system property and specifies the
** directory containing the muttng documentation.\fP
    */
 #ifdef USE_HCACHE
 #if HAVE_QDBM
-  {"muttng_hcache_backend", DT_SYS, R_NONE, 0, "qdbm" },
+  {"madmutt_hcache_backend", DT_SYS, R_NONE, 0, "qdbm" },
 #elif HAVE_GDBM
-  {"muttng_hcache_backend", DT_SYS, R_NONE, 0, "gdbm" },
+  {"madmutt_hcache_backend", DT_SYS, R_NONE, 0, "gdbm" },
 #elif HAVE_DB4
-  {"muttng_hcache_backend", DT_SYS, R_NONE, 0, "db4" },
+  {"madmutt_hcache_backend", DT_SYS, R_NONE, 0, "db4" },
 #else
-  {"muttng_hcache_backend", DT_SYS, R_NONE, 0, "unknown" },
+  {"madmutt_hcache_backend", DT_SYS, R_NONE, 0, "unknown" },
 #endif
   /*
    ** .pp
@@ -1459,14 +1459,14 @@ struct option_t MuttVars[] = {
    ** header chaching's database backend.\fP
    */
 #endif
-  {"muttng_folder_path", DT_SYS, R_NONE, 0, "" },
+  {"madmutt_folder_path", DT_SYS, R_NONE, 0, "" },
   /*
    ** .pp
    ** \fIThis is a read-only system property and, at runtime,
    ** specifies the full path or URI of the folder currently
    ** open (if any).\fP
    */
-  {"muttng_folder_name", DT_SYS, R_NONE, 0, "" },
+  {"madmutt_folder_name", DT_SYS, R_NONE, 0, "" },
   /*
    ** .pp
    ** \fIThis is a read-only system property and, at runtime,
@@ -1476,7 +1476,7 @@ struct option_t MuttVars[] = {
    ** For detection, $$$folder is first taken into account
    ** and simply stripped to form the result when a match is found. For
    ** example, with $$$folder being \fTimap://host\fP and the folder is
** \fTimap://host/INBOX/foo\fP, $$$muttng_folder_name will be just
    ** \fTINBOX/foo\fP.)
    ** .pp
    ** Second, if the initial portion of a name is not $$$folder,
@@ -1485,11 +1485,11 @@ struct option_t MuttVars[] = {
    ** Third and last, the result will be just the name if neither
    ** $$$folder nor a ``/'' were found in the name.
    */
-  {"muttng_pwd", DT_SYS, R_NONE, 0, "" },
+  {"madmutt_pwd", DT_SYS, R_NONE, 0, "" },
   /*
    ** .pp
    ** \fIThis is a read-only system property and, at runtime,
** specifies the current working directory of the muttng
    ** binary.\fP
    */
   {"operating_system", DT_STR, R_NONE, UL &OperatingSystem, "" },
@@ -1758,7 +1758,7 @@ struct option_t MuttVars[] = {
    ** deeper threads to fit on the screen.
    */
 #ifdef USE_NNTP
-  {"nntp_cache_dir", DT_PATH, R_NONE, UL &NewsCacheDir, "~/.muttng"},
+  {"nntp_cache_dir", DT_PATH, R_NONE, UL &NewsCacheDir, "~/.madmutt"},
   /*
    ** .pp
    ** Availability: NNTP
@@ -2592,7 +2592,7 @@ struct option_t MuttVars[] = {
    ** certificate that is signed with one of these CA certificates are 
    ** also automatically accepted.
    ** .pp
-   ** Example: \fTset certificate_file=~/.muttng/certificates\fP
+   ** Example: \fTset certificate_file=~/.madmutt/certificates\fP
    */
 # if defined(_MAKEDOC) || !defined (USE_GNUTLS)
   {"ssl_usesystemcerts", DT_BOOL, R_NONE, OPTSSLSYSTEMCERTS, "yes" },
@@ -3510,7 +3510,7 @@ struct option_t MuttVars[] = {
    ** .pp
    ** When \fIunset\fP, Mutt-ng won't stop when the user presses the terminal's
    ** \fIsusp\fP key, usually \fTCTRL+Z\fP. This is useful if you run Mutt-ng
** inside an xterm using a command like ``\fTxterm -e muttng\fP.''
    */
   {"text_flowed", DT_BOOL, R_NONE, OPTTEXTFLOWED, "no" },
   /*
@@ -280,7 +280,7 @@ struct option_t MuttVars[] = {
   /*
    ** .pp
-   ** If this variable is non-empty, muttng will scan a message's contents
+   ** If this variable is non-empty, madmutt will scan a message's contents
    ** before sending for this regular expression. If it is found, it will
    ** ask for what to do depending on the setting of $$abort_noattach.
@@ -478,7 +478,7 @@ struct option_t MuttVars[] = {
    ** S/MIME and PGP will be used instead of the classic code.
    ** .pp
-   ** \fBNote\fP: You need to use this option in your \fT.muttngrc\fP configuration
+   ** \fBNote\fP: You need to use this option in your \fT.madmuttrc\fP configuration
    ** file as it won't have any effect when used interactively.
    */
@@ -525,7 +525,7 @@ struct option_t MuttVars[] = {
    **
    ** .pp
-   ** Currently, this number must be >= 0 and <= 5 and muttng
+   ** Currently, this number must be >= 0 and <= 5 and madmutt
    ** must be started with \fT-d\fP to enable debugging at all;
    ** enabling at runtime is not possible.
@@ -1001,7 +1001,7 @@ struct option_t MuttVars[] = {
    ** function; \fIgroup-reply\fP will reply to both the sender and the
    ** list.
-   ** Remember: This option works only for mailing lists which are explicitly set in your muttngrc
+   ** Remember: This option works only for mailing lists which are explicitly set in your madmuttrc
    ** configuration file.
    */
@@ -1413,45 +1413,45 @@ struct option_t MuttVars[] = {
   /*
    ** .pp
-   ** \fIThis is a read-only system property and specifies muttng's
+   ** \fIThis is a read-only system property and specifies madmutt's
    ** version string.\fP
    */
@@ -1413,45 +1413,45 @@ struct option_t MuttVars[] = {
   /*
    ** .pp
-   ** \fIThis is a read-only system property and specifies muttng's
+   ** \fIThis is a read-only system property and specifies madmutt's
    ** subversion revision string.\fP
    */
@@ -1413,45 +1413,45 @@ struct option_t MuttVars[] = {
    ** .pp
    ** \fIThis is a read-only system property and specifies the
-   ** directory containing the muttng system-wide configuration.\fP
+   ** directory containing the madmutt system-wide configuration.\fP
    */
@@ -1413,45 +1413,45 @@ struct option_t MuttVars[] = {
    ** .pp
    ** \fIThis is a read-only system property and specifies the
-   ** directory containing the muttng binary.\fP
+   ** directory containing the madmutt binary.\fP
    */
@@ -1413,45 +1413,45 @@ struct option_t MuttVars[] = {
    ** .pp
    ** \fIThis is a read-only system property and specifies the
-   ** directory containing the muttng documentation.\fP
+   ** directory containing the madmutt documentation.\fP
    */
 #ifdef USE_HCACHE
@@ -1476,7 +1476,7 @@ struct option_t MuttVars[] = {
    ** and simply stripped to form the result when a match is found. For
    ** example, with $$$folder being \fTimap://host\fP and the folder is
-   ** \fTimap://host/INBOX/foo\fP, $$$muttng_folder_name will be just
+   ** \fTimap://host/INBOX/foo\fP, $$$madmutt_folder_name will be just
    ** \fTINBOX/foo\fP.)
    ** .pp
@@ -1485,11 +1485,11 @@ struct option_t MuttVars[] = {
    ** .pp
    ** \fIThis is a read-only system property and, at runtime,
-   ** specifies the current working directory of the muttng
+   ** specifies the current working directory of the madmutt
    ** binary.\fP
    */
@@ -3510,7 +3510,7 @@ struct option_t MuttVars[] = {
    ** When \fIunset\fP, Mutt-ng won't stop when the user presses the terminal's
    ** \fIsusp\fP key, usually \fTCTRL+Z\fP. This is useful if you run Mutt-ng
-   ** inside an xterm using a command like ``\fTxterm -e muttng\fP.''
+   ** inside an xterm using a command like ``\fTxterm -e madmutt\fP.''
    */
   {"text_flowed", DT_BOOL, R_NONE, OPTTEXTFLOWED, "no" },